@@ -31,17 +31,22 @@ GNU General Public License for more details.
 #include "layermanager.h"
 #include "soundmanager.h"
 #include "playbackmanager.h"
+#include "colormanager.h"
 #include "preferencemanager.h"
+#include "selectionmanager.h"
 #include "util.h"
 #include "app_util.h"
 
 #include "layercamera.h"
 #include "layersound.h"
+#include "layerbitmap.h"
+#include "layervector.h"
 #include "bitmapimage.h"
 #include "vectorimage.h"
 #include "soundclip.h"
 #include "camera.h"
 
+#include "movieimporter.h"
 #include "movieexporter.h"
 #include "filedialogex.h"
 #include "exportmoviedialog.h"
@@ -49,6 +54,7 @@ GNU General Public License for more details.
 #include "aboutdialog.h"
 #include "doubleprogressdialog.h"
 #include "checkupdatesdialog.h"
+#include "errordialog.h"
 
 
 ActionCommands::ActionCommands(QWidget* parent) : QObject(parent)
@@ -58,11 +64,110 @@ ActionCommands::ActionCommands(QWidget* parent) : QObject(parent)
 
 ActionCommands::~ActionCommands() {}
 
+Status ActionCommands::importMovieVideo()
+{
+    FileDialog fileDialog(mParent);
+    QString filePath = fileDialog.openFile(FileType::MOVIE);
+    if (filePath.isEmpty())
+    {
+        return Status::FAIL;
+    }
+
+    // Show a progress dialog, as this can take a while if you have lots of images.
+    QProgressDialog progressDialog(tr("Importing movie..."), tr("Abort"), 0, 100, mParent);
+    hideQuestionMark(progressDialog);
+    progressDialog.setWindowModality(Qt::WindowModal);
+    progressDialog.setMinimumWidth(250);
+    progressDialog.show();
+
+    QMessageBox information(mParent);
+    information.setIcon(QMessageBox::Warning);
+    information.setText(tr("You are importing a lot of frames, beware this could take some time. Are you sure you want to proceed?"));
+    information.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
+    information.setDefaultButton(QMessageBox::Yes);
+
+    MovieImporter importer(this);
+    importer.setCore(mEditor);
+
+    connect(&progressDialog, &QProgressDialog::canceled, &importer, &MovieImporter::cancel);
+
+    Status st = importer.run(filePath, mEditor->playback()->fps(), FileType::MOVIE, [&progressDialog](int prog) {
+        progressDialog.setValue(prog);
+        QApplication::processEvents();
+    }, [&progressDialog](QString progMessage) {
+        progressDialog.setLabelText(progMessage);
+    }, [&information]() {
+
+        int ret = information.exec();
+        return ret == QMessageBox::Yes;
+    });
+
+    if (!st.ok() && st != Status::CANCELED)
+    {
+        ErrorDialog errorDialog(st.title(), st.description(), st.details().html(), mParent);
+        errorDialog.exec();
+    }
+
+    mEditor->layers()->notifyAnimationLengthChanged();
+
+    progressDialog.setValue(100);
+    progressDialog.close();
+
+    return Status::OK;
+}
+
+Status ActionCommands::importMovieAudio()
+{
+    FileDialog fileDialog(mParent);
+    QString filePath = fileDialog.openFile(FileType::MOVIE);
+    if (filePath.isEmpty())
+    {
+        return Status::FAIL;
+    }
+
+    // Show a progress dialog, as this can take a while if you have lots of images.
+    QProgressDialog progressDialog(tr("Importing movie audio..."), tr("Abort"), 0, 100, mParent);
+    hideQuestionMark(progressDialog);
+    progressDialog.setWindowModality(Qt::WindowModal);
+    progressDialog.show();
+
+    MovieImporter importer(this);
+    importer.setCore(mEditor);
+
+    connect(&progressDialog, &QProgressDialog::canceled, &importer, &MovieImporter::cancel);
+
+    Status st = importer.run(filePath, mEditor->playback()->fps(), FileType::SOUND, [&progressDialog](int prog) {
+        progressDialog.setValue(prog);
+        QApplication::processEvents();
+    }, [](QString progressMessage) {
+        Q_UNUSED(progressMessage)
+        // Not neeeded
+    }, []() {
+        return true;
+    });
+
+    if (!st.ok() && st != Status::CANCELED)
+    {
+        ErrorDialog errorDialog(st.title(), st.description(), st.details().html(), mParent);
+        errorDialog.exec();
+    }
+
+    mEditor->layers()->notifyAnimationLengthChanged();
+
+    progressDialog.setValue(100);
+    progressDialog.close();
+
+    return Status::OK;
+}
+
 Status ActionCommands::importSound()
 {
     Layer* layer = mEditor->layers()->currentLayer();
-    Q_ASSERT(layer);
-    NULLReturn(layer, Status::FAIL);
+    if (layer == nullptr)
+    {
+        Q_ASSERT(layer);
+        return Status::FAIL;
+    }
 
     if (layer->type() != Layer::SOUND)
     {
@@ -99,22 +204,14 @@ Status ActionCommands::importSound()
 
 
     int currentFrame = mEditor->currentFrame();
-    SoundClip* key = nullptr;
 
-    if (layer->keyExists(currentFrame))
+    SoundClip* key = static_cast<SoundClip*>(mEditor->addNewKey());
+
+    if (key == nullptr)
     {
-        key = static_cast<SoundClip*>(layer->getKeyFrameAt(currentFrame));
-        if (!key->fileName().isEmpty())
-        {
-            QMessageBox::warning(nullptr, "",
-                                 tr("A sound clip already exists on this frame! Please select another frame or layer."));
-            return Status::SAFE;
-        }
-    }
-    else
-    {
-        key = new SoundClip;
-        layer->addKeyFrame(currentFrame, key);
+        // Probably tried to modify a hidden layer or something like that
+        // Let Editor handle the warnings
+        return Status::SAFE;
     }
 
     FileDialog fileDialog(mParent);
@@ -125,7 +222,16 @@ Status ActionCommands::importSound()
         return Status::SAFE;
     }
 
-    Status st = mEditor->sound()->loadSound(key, strSoundFile);
+    Status st = Status::FAIL;
+
+    if (strSoundFile.endsWith(".wav"))
+    {
+        st = mEditor->sound()->loadSound(key, strSoundFile);
+    }
+    else
+    {
+        st = convertSoundToWav(strSoundFile);
+    }
 
     if (!st.ok())
     {
@@ -135,6 +241,36 @@ Status ActionCommands::importSound()
     return st;
 }
 
+Status ActionCommands::convertSoundToWav(const QString& filePath)
+{
+    QProgressDialog progressDialog(tr("Importing sound..."), tr("Abort"), 0, 100, mParent);
+    hideQuestionMark(progressDialog);
+    progressDialog.setWindowModality(Qt::WindowModal);
+    progressDialog.show();
+
+    MovieImporter importer(this);
+    importer.setCore(mEditor);
+
+    Status st = importer.run(filePath, mEditor->playback()->fps(), FileType::SOUND, [&progressDialog](int prog) {
+        progressDialog.setValue(prog);
+        QApplication::processEvents();
+    }, [](QString progressMessage) {
+        Q_UNUSED(progressMessage)
+        // Not needed
+    }, []() {
+        return true;
+    });
+
+    connect(&progressDialog, &QProgressDialog::canceled, &importer, &MovieImporter::cancel);
+
+    if (!st.ok() && st != Status::CANCELED)
+    {
+        ErrorDialog errorDialog(st.title(), st.description(), st.details().html(), mParent);
+        errorDialog.exec();
+    }
+    return st;
+}
+
 Status ActionCommands::exportGif()
 {
     // exporting gif
@@ -152,7 +288,7 @@ Status ActionCommands::exportMovie(bool isGif)
     OnScopeExit(dialog->deleteLater());
 
     dialog->init();
-    
+
     std::vector< std::pair<QString, QSize> > camerasInfo;
     auto cameraLayers = mEditor->object()->getLayersByType< LayerCamera >();
     for (LayerCamera* i : cameraLayers)
@@ -182,7 +318,7 @@ Status ActionCommands::exportMovie(bool isGif)
 
     dialog->setDefaultRange(1, length, lengthWithSounds);
     dialog->exec();
-    
+
     if (dialog->result() == QDialog::Rejected)
     {
         return Status::SAFE;
@@ -239,34 +375,48 @@ Status ActionCommands::exportMovie(bool isGif)
         }
     );
 
-    if (st.ok() && QFile::exists(strMoviePath))
+    if (st.ok())
     {
-        if (isGif) {
-            auto btn = QMessageBox::question(mParent, "Pencil2D",
-                                             tr("Finished. Open file location?"));
+        if (QFile::exists(strMoviePath))
+        {
+            if (isGif) {
+                auto btn = QMessageBox::question(mParent, "Pencil2D",
+                                                 tr("Finished. Open file location?"));
 
+                if (btn == QMessageBox::Yes)
+                {
+                    QString path = dialog->getAbsolutePath();
+                    QDesktopServices::openUrl(QUrl::fromLocalFile(path));
+                }
+                return Status::OK;
+            }
+            auto btn = QMessageBox::question(mParent, "Pencil2D",
+                                             tr("Finished. Open movie now?", "When movie export done."));
             if (btn == QMessageBox::Yes)
             {
-                QString path = dialog->getAbsolutePath();
-                QDesktopServices::openUrl(QUrl::fromLocalFile(path));
+                QDesktopServices::openUrl(QUrl::fromLocalFile(strMoviePath));
             }
-            return Status::OK;
         }
-        auto btn = QMessageBox::question(mParent, "Pencil2D",
-                                         tr("Finished. Open movie now?", "When movie export done."));
-        if (btn == QMessageBox::Yes)
+        else
         {
-            QDesktopServices::openUrl(QUrl::fromLocalFile(strMoviePath));
+            ErrorDialog errorDialog(tr("Unknown export error"), tr("The export did not produce any errors, however we can't find the output file. Your export may not have completed successfully."), QString(), mParent);
+            errorDialog.exec();
         }
     }
-    return Status::OK;
+    else if(st != Status::CANCELED)
+    {
+        ErrorDialog errorDialog(st.title(), st.description(), st.details().html(), mParent);
+        errorDialog.exec();
+    }
+
+    return st;
 }
 
 Status ActionCommands::exportImageSequence()
 {
     auto dialog = new ExportImageDialog(mParent, FileType::IMAGE_SEQUENCE);
     OnScopeExit(dialog->deleteLater());
-    
+
     dialog->init();
 
     std::vector< std::pair<QString, QSize> > camerasInfo;
@@ -417,6 +567,16 @@ void ActionCommands::flipSelectionY()
     mEditor->flipSelection(flipVertical);
 }
 
+void ActionCommands::selectAll()
+{
+    mEditor->selectAll();
+}
+
+void ActionCommands::deselectAll()
+{
+    mEditor->deselectAll();
+}
+
 void ActionCommands::ZoomIn()
 {
     mEditor->view()->scaleUp();
@@ -522,8 +682,6 @@ Status ActionCommands::addNewKey()
         mEditor->view()->updateViewTransforms();
     }
 
-    mEditor->layers()->notifyAnimationLengthChanged();
-
     return Status::OK;
 }
 
@@ -606,7 +764,7 @@ Status ActionCommands::addNewBitmapLayer()
     bool ok;
     QString text = QInputDialog::getText(nullptr, tr("Layer Properties"),
                                          tr("Layer name:"), QLineEdit::Normal,
-                                         nameSuggest(tr("Bitmap Layer")), &ok);
+                                         mEditor->layers()->nameSuggestLayer(tr("Bitmap Layer")), &ok);
     if (ok && !text.isEmpty())
     {
         mEditor->layers()->createBitmapLayer(text);
@@ -619,7 +777,7 @@ Status ActionCommands::addNewVectorLayer()
     bool ok;
     QString text = QInputDialog::getText(nullptr, tr("Layer Properties"),
                                          tr("Layer name:"), QLineEdit::Normal,
-                                         nameSuggest(tr("Vector Layer")), &ok);
+                                         mEditor->layers()->nameSuggestLayer(tr("Vector Layer")), &ok);
     if (ok && !text.isEmpty())
     {
         mEditor->layers()->createVectorLayer(text);
@@ -630,9 +788,9 @@ Status ActionCommands::addNewVectorLayer()
 Status ActionCommands::addNewCameraLayer()
 {
     bool ok;
-    QString text = QInputDialog::getText(nullptr, tr("Layer Properties"),
+    QString text = QInputDialog::getText(nullptr, tr("Layer Properties", "A popup when creating a new layer"),
                                          tr("Layer name:"), QLineEdit::Normal,
-                                         nameSuggest(tr("Camera Layer")), &ok);
+                                         mEditor->layers()->nameSuggestLayer(tr("Camera Layer")), &ok);
     if (ok && !text.isEmpty())
     {
         mEditor->layers()->createCameraLayer(text);
@@ -645,7 +803,7 @@ Status ActionCommands::addNewSoundLayer()
     bool ok = false;
     QString strLayerName = QInputDialog::getText(nullptr, tr("Layer Properties"),
                                                  tr("Layer name:"), QLineEdit::Normal,
-                                                 nameSuggest(tr("Sound Layer")), &ok);
+                                                 mEditor->layers()->nameSuggestLayer(tr("Sound Layer")), &ok);
     if (ok && !strLayerName.isEmpty())
     {
         Layer* layer = mEditor->layers()->createSoundLayer(strLayerName);
@@ -661,7 +819,7 @@ Status ActionCommands::deleteCurrentLayer()
 
     int ret = QMessageBox::warning(mParent,
                                    tr("Delete Layer", "Windows title of Delete current layer pop-up."),
-                                   tr("Are you sure you want to delete layer: ") + strLayerName + " ?",
+                                   tr("Are you sure you want to delete layer: %1?").arg(strLayerName),
                                    QMessageBox::Ok | QMessageBox::Cancel,
                                    QMessageBox::Ok);
     if (ret == QMessageBox::Ok)
@@ -676,33 +834,37 @@ Status ActionCommands::deleteCurrentLayer()
     return Status::OK;
 }
 
-QString ActionCommands::nameSuggest(QString s)
+void ActionCommands::setLayerVisibilityIndex(int index)
 {
-    LayerManager* layerMgr = mEditor->layers();
-    // if no layers: return 's'
-    if (layerMgr->count() == 0)
-    {
-        return s;
-    }
-    QVector<QString> sLayers;
-    // fill Vector with layer names
-    for (int i = 0; i < layerMgr->count(); i++)
-    {
-        sLayers.append(layerMgr->getLayer(i)->name());
-    }
-    // if 's' is not in list, then return 's'
-    if (!sLayers.contains(s))
-    {
-        return s;
-    }
-    int j = 2;
-    QString tmp = s;
-    do {
-        tmp = s + " " + QString::number(j++);
-    } while (sLayers.contains(tmp));
-    return tmp;
+    mEditor->setLayerVisibility(static_cast<LayerVisibility>(index));
 }
 
+void ActionCommands::changeKeyframeLineColor()
+{
+    if (mEditor->layers()->currentLayer()->type() == Layer::BITMAP &&
+            mEditor->layers()->currentLayer()->keyExists(mEditor->currentFrame()))
+    {
+        QRgb color = mEditor->color()->frontColor().rgb();
+        LayerBitmap* layer = static_cast<LayerBitmap*>(mEditor->layers()->currentLayer());
+        layer->getBitmapImageAtFrame(mEditor->currentFrame())->fillNonAlphaPixels(color);
+        mEditor->updateFrame(mEditor->currentFrame());
+    }
+}
+
+void ActionCommands::changeallKeyframeLineColor()
+{
+    if (mEditor->layers()->currentLayer()->type() == Layer::BITMAP)
+    {
+        QRgb color = mEditor->color()->frontColor().rgb();
+        LayerBitmap* layer = static_cast<LayerBitmap*>(mEditor->layers()->currentLayer());
+        for (int i = layer->firstKeyFramePosition(); i <= layer->getMaxKeyFramePosition(); i++)
+        {
+            if (layer->keyExists(i))
+                layer->getBitmapImageAtFrame(i)->fillNonAlphaPixels(color);
+        }
+        mEditor->updateFrame(mEditor->currentFrame());
+    }
+}
 
 void ActionCommands::help()
 {
@@ -752,6 +914,16 @@ void ActionCommands::checkForUpdates()
     dialog.exec();
 }
 
+// This action is a temporary measure until we have an automated recover mechanism in place
+void ActionCommands::openTemporaryDirectory()
+{
+    int ret = QMessageBox::warning(mParent, tr("Warning"), tr("The temporary directory is meant to be used only by Pencil2D. Do not modify it unless you know what you are doing."), QMessageBox::Cancel, QMessageBox::Ok);
+    if (ret == QMessageBox::Ok)
+    {
+        QDesktopServices::openUrl(QUrl::fromLocalFile(QDir::temp().filePath("Pencil2D")));
+    }
+}
+
 void ActionCommands::about()
 {
     AboutDialog* aboutBox = new AboutDialog(mParent);
