@@ -26,18 +26,20 @@ GNU General Public License for more details.
 #include <QListWidgetItem>
 #include <QInputDialog>
 #include <QColorDialog>
-#include <QToolBar>
 #include <QMessageBox>
 #include <QPushButton>
 #include <QSettings>
 #include <QMenu>
+#include <QtMath>
+#include <QScrollBar>
+#include <QAbstractItemModel>
+#include <QPainter>
 
 // Project
-#include "colourref.h"
+#include "colorref.h"
 #include "object.h"
 #include "editor.h"
-#include "colorbox.h"
-#include "scribblearea.h"
+#include "layerbitmap.h"
 #include "colormanager.h"
 
 
@@ -57,6 +59,11 @@ void ColorPaletteWidget::initUI()
 {
     QSettings settings(PENCIL2D, PENCIL2D);
     int colorGridSize = settings.value("PreferredColorGridSize", 34).toInt();
+    mFitSwatches = settings.value("FitSwatchSize", false).toBool();
+    if (mFitSwatches)
+    {
+        fitSwatchSize();
+    }
 
     mIconSize = QSize(colorGridSize, colorGridSize);
 
@@ -80,27 +87,39 @@ void ColorPaletteWidget::initUI()
     palettePreferences();
 
     connect(ui->colorListWidget, &QListWidget::itemClicked, this, &ColorPaletteWidget::clickColorListItem);
+    connect(ui->colorListWidget->model(), &QAbstractItemModel::rowsMoved, this, &ColorPaletteWidget::onRowsMoved);
 
-    connect(ui->colorListWidget, &QListWidget::itemDoubleClicked, this, &ColorPaletteWidget::changeColourName);
+    connect(ui->colorListWidget, &QListWidget::itemDoubleClicked, this, &ColorPaletteWidget::changeColorName);
     connect(ui->colorListWidget, &QListWidget::itemChanged, this, &ColorPaletteWidget::onItemChanged);
 
     connect(ui->addColorButton, &QPushButton::clicked, this, &ColorPaletteWidget::clickAddColorButton);
     connect(ui->colorDialogButton, &QPushButton::clicked, this, &ColorPaletteWidget::clickColorDialogButton);
     connect(ui->removeColorButton, &QPushButton::clicked, this, &ColorPaletteWidget::clickRemoveColorButton);
     connect(ui->colorListWidget, &QListWidget::customContextMenuRequested, this, &ColorPaletteWidget::showContextMenu);
+
+    connect(editor(), &Editor::objectLoaded, this, &ColorPaletteWidget::updateUI);
 }
 
 void ColorPaletteWidget::updateUI()
 {
+    mObject = mEditor->object();
     refreshColorList();
     updateGridUI();
 }
 
-void ColorPaletteWidget::showContextMenu(const QPoint &pos)
+void ColorPaletteWidget::setCore(Editor* editor)
+{
+    mEditor = editor;
+    mObject = mEditor->object();
+}
+
+void ColorPaletteWidget::showContextMenu(const QPoint& pos)
 {
     QPoint globalPos = ui->colorListWidget->mapToGlobal(pos);
 
-    QMenu* menu = new QMenu();
+    QMenu* menu = new QMenu;
+    connect(menu, &QMenu::triggered, menu, &QMenu::deleteLater);
+
     menu->addAction(tr("Add"), this, &ColorPaletteWidget::addItem, 0);
     menu->addAction(tr("Replace"),  this, &ColorPaletteWidget::replaceItem, 0);
     menu->addAction(tr("Remove"), this, &ColorPaletteWidget::removeItem, 0);
@@ -111,15 +130,25 @@ void ColorPaletteWidget::showContextMenu(const QPoint &pos)
 void ColorPaletteWidget::addItem()
 {
     QSignalBlocker b(ui->colorListWidget);
-    QColor newColour = editor()->color()->frontColor();
+    QColor newColor = mEditor->color()->frontColor();
 
-    // add in front of selected color
-    int colorIndex = ui->colorListWidget->currentRow()+1;
+    // add at bottom
+    int colorIndex = ui->colorListWidget->count();
 
-    ColourRef ref(newColour);
+    ColorRef ref(newColor);
+
+    mObject->addColorAtIndex(colorIndex, ref);
 
-    editor()->object()->addColourAtIndex(colorIndex, ref);
     refreshColorList();
+
+    if (mFitSwatches)
+    {
+        fitSwatchSize();
+    }
+
+    QListWidgetItem* item = ui->colorListWidget->item(colorIndex);
+    ui->colorListWidget->editItem(item);
+    ui->colorListWidget->scrollToItem(item);
 }
 
 void ColorPaletteWidget::replaceItem()
@@ -127,12 +156,12 @@ void ColorPaletteWidget::replaceItem()
     QSignalBlocker b(ui->colorListWidget);
     int index = ui->colorListWidget->currentRow();
 
-    QColor newColour = editor()->color()->frontColor();
+    QColor newColor = mEditor->color()->frontColor();
 
     if (index >= 0)
     {
-        updateItemColor(index, newColour);
-        emit colorChanged(newColour);
+        updateItemColor(index, newColor);
+        emit colorChanged(newColor);
         ui->colorListWidget->setCurrentRow(index);
     }
 }
@@ -159,7 +188,7 @@ void ColorPaletteWidget::selectColorNumber(int colorNumber)
     ui->colorListWidget->setCurrentRow(colorNumber);
 }
 
-int ColorPaletteWidget::currentColourNumber()
+int ColorPaletteWidget::currentColorNumber()
 {
     if (ui->colorListWidget->currentRow() < 0)
     {
@@ -176,61 +205,61 @@ void ColorPaletteWidget::refreshColorList()
         ui->colorListWidget->clear();
     }
 
-    QPixmap originalColourSwatch(mIconSize);
-    QPainter swatchPainter(&originalColourSwatch);
-    swatchPainter.drawTiledPixmap(0, 0, mIconSize.width(), mIconSize.height(), QPixmap(":/background/checkerboard.png"));
-    swatchPainter.end();
-    QPixmap colourSwatch;
+    QPixmap originalColorSwatch(mIconSize);
+    QPainter painter(&originalColorSwatch);
+    painter.drawTiledPixmap(0, 0, mIconSize.width(), mIconSize.height(), QPixmap(":/background/checkerboard.png"));
+    painter.end();
+
     QPen borderShadow(QColor(0, 0, 0, 200), 1, Qt::DotLine, Qt::FlatCap, Qt::MiterJoin);
-    QVector<qreal> dashPattern;
-    dashPattern << 4 << 4;
+    QVector<qreal> dashPattern{ 4, 4 };
     borderShadow.setDashPattern(dashPattern);
+
     QPen borderHighlight(borderShadow);
     borderHighlight.setColor(QColor(255, 255, 255, 200));
     borderHighlight.setDashOffset(4);
 
-    int colourCount = editor()->object()->getColourCount();
+    const int colorCount = mObject->getColorCount();
 
-    for (int i = 0; i < colourCount; i++)
+    for (int i = 0; i < colorCount; i++)
     {
-        const ColourRef colourRef = editor()->object()->getColour(i);
-        QListWidgetItem* colourItem = new QListWidgetItem(ui->colorListWidget);
+        const ColorRef colorRef = mObject->getColor(i);
+        QListWidgetItem* colorItem = new QListWidgetItem(ui->colorListWidget);
 
         if (ui->colorListWidget->viewMode() != QListView::IconMode)
         {
-            colourItem->setText(colourRef.name);
+            colorItem->setText(colorRef.name);
         }
         else
         {
-            colourItem->setToolTip(colourRef.name);
+            colorItem->setToolTip(colorRef.name);
         }
-        colourSwatch = originalColourSwatch;
-        swatchPainter.begin(&colourSwatch);
-        swatchPainter.fillRect(0, 0, mIconSize.width(), mIconSize.height(), colourRef.colour);
+        QPixmap colorSwatch = originalColorSwatch;
+        QPainter swatchPainter(&colorSwatch);
+        swatchPainter.fillRect(0, 0, mIconSize.width(), mIconSize.height(), colorRef.color);
 
         QIcon swatchIcon;
-        swatchIcon.addPixmap(colourSwatch, QIcon::Normal);
+        swatchIcon.addPixmap(colorSwatch, QIcon::Normal);
 
         // Draw selection border
-        if(ui->colorListWidget->viewMode() == QListView::IconMode) {
+        if (ui->colorListWidget->viewMode() == QListView::IconMode)
+        {
             swatchPainter.setPen(borderHighlight);
             swatchPainter.drawRect(0, 0, mIconSize.width() - 1, mIconSize.height() - 1);
             swatchPainter.setPen(borderShadow);
             swatchPainter.drawRect(0, 0, mIconSize.width() - 1, mIconSize.height() - 1);
         }
-        swatchIcon.addPixmap(colourSwatch, QIcon::Selected);
+        swatchIcon.addPixmap(colorSwatch, QIcon::Selected);
 
-        colourItem->setIcon(swatchIcon);
-        swatchPainter.end();
-        colourItem->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled | Qt::ItemIsEditable);
+        colorItem->setIcon(swatchIcon);
+        colorItem->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled | Qt::ItemIsEditable | Qt::ItemIsDragEnabled);
 
-        ui->colorListWidget->addItem(colourItem);
+        ui->colorListWidget->addItem(colorItem);
     }
     updateGridUI();
     update();
 }
 
-void ColorPaletteWidget::changeColourName(QListWidgetItem* item)
+void ColorPaletteWidget::changeColorName(QListWidgetItem* item)
 {
     Q_ASSERT(item != NULL);
 
@@ -241,14 +270,14 @@ void ColorPaletteWidget::changeColourName(QListWidgetItem* item)
         {
             bool ok;
             QString text = QInputDialog::getText(this,
-                                                 tr("Colour name"),
-                                                 tr("Colour name"),
+                                                 tr("Color name"),
+                                                 tr("Color name"),
                                                  QLineEdit::Normal,
-                                                 editor()->object()->getColour(colorNumber).name,
+                                                 mObject->getColor(colorNumber).name,
                                                  &ok);
             if (ok && !text.isEmpty())
             {
-                editor()->object()->renameColour(colorNumber, text);
+                mObject->renameColor(colorNumber, text);
                 refreshColorList();
             }
         }
@@ -259,7 +288,55 @@ void ColorPaletteWidget::onItemChanged(QListWidgetItem* item)
 {
     int index = ui->colorListWidget->row(item);
     QString newColorName = item->text();
-    editor()->object()->renameColour(index, newColorName);
+    mObject->renameColor(index, newColorName);
+}
+
+void ColorPaletteWidget::onRowsMoved(const QModelIndex &parent, int start, int end, const QModelIndex &destination, int row)
+{
+    Q_UNUSED(parent)
+    Q_UNUSED(destination)
+    Q_UNUSED(end)
+
+    int startIndex, endIndex;
+    if (start < row)
+    {
+        row -= 1; // TODO: Is this a bug?
+        if (start == row) { return; }
+
+        startIndex = start;
+        endIndex = row;
+
+        mObject->movePaletteColor(startIndex, endIndex);
+
+        mObject->addColor(mObject->getColor(startIndex));
+        mObject->moveVectorColor(startIndex, mObject->getColorCount() - 1);
+        for (int i = startIndex; i < endIndex; i++)
+        {
+            mObject->moveVectorColor(i + 1, i);
+        }
+        mObject->moveVectorColor(mObject->getColorCount() - 1, endIndex);
+    }
+    else
+    {
+        if (start == row) { return; }
+
+        startIndex = start;
+        endIndex = row;
+
+        mObject->movePaletteColor(startIndex, endIndex);
+
+        mObject->addColor(mObject->getColor(startIndex));
+        mObject->moveVectorColor(startIndex, mObject->getColorCount() - 1);
+        for (int i = startIndex; i > endIndex; i--)
+        {
+            mObject->moveVectorColor(i - 1, i);
+        }
+        mObject->moveVectorColor(mObject->getColorCount() - 1, endIndex);
+    }
+
+    mObject->removeColor(mObject->getColorCount() - 1);
+
+    refreshColorList();
 }
 
 void ColorPaletteWidget::clickColorListItem(QListWidgetItem* currentItem)
@@ -296,13 +373,16 @@ void ColorPaletteWidget::palettePreferences()
     ui->palettePref->setStyleSheet(buttonStylesheet);
     ui->palettePref->addAction(ui->listModeAction);
     ui->palettePref->addAction(ui->gridModeAction);
+
     ui->palettePref->addAction(mSeparator);
     ui->palettePref->addAction(ui->smallSwatchAction);
     ui->palettePref->addAction(ui->mediumSwatchAction);
     ui->palettePref->addAction(ui->largeSwatchAction);
+    ui->palettePref->addAction(ui->fitSwatchAction);
 
-    if (mIconSize.width() > 30) ui->largeSwatchAction->setChecked(true);
-    else if (mIconSize.width() > 20) ui->mediumSwatchAction->setChecked(true);
+    if (mFitSwatches) ui->fitSwatchAction->setChecked(true);
+    else if (mIconSize.width() > MEDIUM_ICON_SIZE) ui->largeSwatchAction->setChecked(true);
+    else if (mIconSize.width() > MIN_ICON_SIZE) ui->mediumSwatchAction->setChecked(true);
     else ui->smallSwatchAction->setChecked(true);
 
     if (ui->colorListWidget->viewMode() == QListView::ListMode)
@@ -312,6 +392,7 @@ void ColorPaletteWidget::palettePreferences()
 
     connect(ui->listModeAction, &QAction::triggered, this, &ColorPaletteWidget::setListMode);
     connect(ui->gridModeAction, &QAction::triggered, this, &ColorPaletteWidget::setGridMode);
+    connect(ui->fitSwatchAction, &QAction::triggered, this, &ColorPaletteWidget::fitSwatchSize);
     connect(ui->smallSwatchAction, &QAction::triggered, this, &ColorPaletteWidget::setSwatchSizeSmall);
     connect(ui->mediumSwatchAction, &QAction::triggered, this, &ColorPaletteWidget::setSwatchSizeMedium);
     connect(ui->largeSwatchAction, &QAction::triggered, this, &ColorPaletteWidget::setSwatchSizeLarge);
@@ -320,8 +401,12 @@ void ColorPaletteWidget::palettePreferences()
 void ColorPaletteWidget::setListMode()
 {
     ui->colorListWidget->setViewMode(QListView::ListMode);
-    ui->colorListWidget->setMovement(QListView::Static);
+    ui->colorListWidget->setDragDropMode(QAbstractItemView::InternalMove);
     ui->colorListWidget->setGridSize(QSize(-1, -1));
+    if (mFitSwatches)
+    {
+        fitSwatchSize();
+    }
     updateUI();
 
     QSettings settings(PENCIL2D, PENCIL2D);
@@ -334,55 +419,121 @@ void ColorPaletteWidget::setGridMode()
     ui->colorListWidget->setMovement(QListView::Static); // TODO: update swatch index on move
     ui->colorListWidget->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
     ui->colorListWidget->setGridSize(QSize(mIconSize.width() + 1, mIconSize.height() + 1));
-
+    if (mFitSwatches)
+    {
+        fitSwatchSize();
+    }
     updateUI();
 
     QSettings settings(PENCIL2D, PENCIL2D);
     settings.setValue("ColorPaletteViewMode", "GridMode");
 }
 
-void ColorPaletteWidget::resizeEvent(QResizeEvent* event)
-{
-    updateUI();
-    QWidget::resizeEvent(event);
-}
-
 void ColorPaletteWidget::setSwatchSizeSmall()
 {
-    if (mIconSize.width() > 18)
+    if (mIconSize.width() > MIN_ICON_SIZE)
     {
-        mIconSize = QSize(14, 14);
+        mIconSize = QSize(MIN_ICON_SIZE, MIN_ICON_SIZE);
         updateUI();
 
+        mFitSwatches = false;
         QSettings settings(PENCIL2D, PENCIL2D);
-        settings.setValue("PreferredColorGridSize", 14);
+        settings.setValue("PreferredColorGridSize", MIN_ICON_SIZE);
+        settings.setValue("FitSwatchSize", false);
     }
 }
 
 void ColorPaletteWidget::setSwatchSizeMedium()
 {
-    if (mIconSize.width() < 20 || mIconSize.width() > 30)
+    if (mIconSize.width() != MEDIUM_ICON_SIZE)
     {
-        mIconSize = QSize(26, 26);
+        mIconSize = QSize(MEDIUM_ICON_SIZE, MEDIUM_ICON_SIZE);
         updateUI();
 
+        mFitSwatches = false;
         QSettings settings(PENCIL2D, PENCIL2D);
-        settings.setValue("PreferredColorGridSize", 26);
+        settings.setValue("PreferredColorGridSize", MEDIUM_ICON_SIZE);
+        settings.setValue("FitSwatchSize", false);
     }
 }
 
 void ColorPaletteWidget::setSwatchSizeLarge()
 {
-    if (mIconSize.width() < 30)
+    if (mIconSize.width() < MAX_ICON_SIZE)
     {
-        mIconSize = QSize(34, 34);
+        mIconSize = QSize(MAX_ICON_SIZE, MAX_ICON_SIZE);
         updateUI();
 
+        mFitSwatches = false;
         QSettings settings(PENCIL2D, PENCIL2D);
-        settings.setValue("PreferredColorGridSize", 34);
+        settings.setValue("PreferredColorGridSize", MAX_ICON_SIZE);
+        settings.setValue("FitSwatchSize", false);
     }
 }
 
+void ColorPaletteWidget::adjustSwatches()
+{
+    if (mFitSwatches)
+        fitSwatchSize();
+}
+
+void ColorPaletteWidget::fitSwatchSize()
+{
+    int height = ui->colorListWidget->height();
+    int width = ui->colorListWidget->width();
+    int hScrollBar = ui->colorListWidget->horizontalScrollBar()->geometry().height() + 6;
+    int vScrollBar = ui->colorListWidget->verticalScrollBar()->geometry().width() * 2;
+    int colorCount = editor()->object()->getColorCount();
+    int size;
+
+    if (ui->colorListWidget->viewMode() == QListView::ListMode)
+    {
+        size = qFloor((height - hScrollBar - (4 * colorCount)) / colorCount);
+        if (size < MIN_ICON_SIZE) size = MIN_ICON_SIZE;
+        if (size > MAX_ICON_SIZE) size = MAX_ICON_SIZE;
+    }
+    else
+    {
+        bool proceed = true;
+        size = MIN_ICON_SIZE;
+        while (proceed)
+        {
+            int columns = (width - vScrollBar) / size;
+            int rows = static_cast<int>(qCeil(colorCount / columns));
+            if (height - hScrollBar > rows * (size + 6))
+            {
+                size++;
+                if (size == MAX_ICON_SIZE)
+                {
+                    proceed = false;
+                }
+            }
+            else
+            {
+                proceed = false;
+            }
+        }
+    }
+    mIconSize = QSize(size, size);
+
+    updateUI();
+
+    mFitSwatches = true;
+    QSettings settings(PENCIL2D, PENCIL2D);
+    settings.setValue("PreferredColorGridSize", size);
+    settings.setValue("FitSwatchSize", true);
+}
+
+void ColorPaletteWidget::resizeEvent(QResizeEvent* event)
+{
+    updateUI();
+    if (mFitSwatches)
+    {
+        fitSwatchSize();
+    }
+    QWidget::resizeEvent(event);
+}
+
 void ColorPaletteWidget::updateGridUI()
 {
     if (ui->colorListWidget->viewMode() == QListView::IconMode) {
@@ -419,26 +570,30 @@ void ColorPaletteWidget::clickAddColorButton()
 {
     QColor prevColor = Qt::white;
 
-    QColor newColour;
+    QColor newColor;
 
     if (mIsColorDialog)
-        newColour = QColorDialog::getColor(prevColor.rgba(), this, QString(), QColorDialog::ShowAlphaChannel);
-    else 
-        newColour = editor()->color()->frontColor();
+        newColor = QColorDialog::getColor(prevColor.rgba(), this, QString(), QColorDialog::ShowAlphaChannel);
+    else
+        newColor = mEditor->color()->frontColor();
 
-    if (!newColour.isValid())
+    if (!newColor.isValid())
     {
         return; // User canceled operation
     }
 
-    int colorIndex = editor()->object()->getColourCount();
-    ColourRef ref(newColour);
+    int colorIndex = mObject->getColorCount();
+    ColorRef ref(newColor);
 
-    editor()->object()->addColour(ref);
+    mObject->addColor(ref);
     refreshColorList();
 
     editor()->color()->setColorNumber(colorIndex);
-    editor()->color()->setColor(ref.colour);
+    editor()->color()->setColor(ref.color);
+    if (mFitSwatches)
+    {
+        fitSwatchSize();
+    }
 }
 
 void ColorPaletteWidget::clickRemoveColorButton()
@@ -450,30 +605,34 @@ void ColorPaletteWidget::clickRemoveColorButton()
         // items are not deleted by qt, it has to be done manually
         // delete should happen before removing the color from from palette
         // as the palette will be one ahead and crash otherwise
-        if (editor()->object()->isColourInUse(index))
+        if (mObject->isColorInUse(index))
         {
             bool accepted = false;
             if (!mMultipleSelected)
                 accepted = showPaletteWarning();
 
-            if ((accepted || mMultipleSelected) && editor()->object()->getColourCount() > 1)
+            if ((accepted || mMultipleSelected) && mObject->getColorCount() > 1)
             {
                 delete item;
-                editor()->object()->removeColour(index);
+                mObject->removeColor(index);
             }
         }
-        else if (editor()->object()->getColourCount() > 1)
+        else if (mObject->getColorCount() > 1)
         {
             delete item;
-            editor()->object()->removeColour(index);
+            mObject->removeColor(index);
         }
-        else if (editor()->object()->getColourCount() == 1)
+        else if (mObject->getColorCount() == 1)
         {
             showPaletteReminder();
         }
-        editor()->updateCurrentFrame();
+        mEditor->updateCurrentFrame();
     }
     mMultipleSelected = false;
+    if (mFitSwatches)
+    {
+        fitSwatchSize();
+    }
 }
 
 bool ColorPaletteWidget::showPaletteWarning()
@@ -503,8 +662,8 @@ void ColorPaletteWidget::showPaletteReminder()
 
 void ColorPaletteWidget::updateItemColor(int itemIndex, QColor newColor)
 {
-    QPixmap colourSwatch(mIconSize);
-    QPainter swatchPainter(&colourSwatch);
+    QPixmap colorSwatch(mIconSize);
+    QPainter swatchPainter(&colorSwatch);
     swatchPainter.drawTiledPixmap(0, 0, mIconSize.width(), mIconSize.height(), QPixmap(":/background/checkerboard.png"));
     swatchPainter.fillRect(0, 0, mIconSize.width(), mIconSize.height(), newColor);
 
@@ -517,7 +676,7 @@ void ColorPaletteWidget::updateItemColor(int itemIndex, QColor newColor)
     borderHighlight.setDashOffset(4);
 
     QIcon swatchIcon;
-    swatchIcon.addPixmap(colourSwatch, QIcon::Normal);
+    swatchIcon.addPixmap(colorSwatch, QIcon::Normal);
 
     if(ui->colorListWidget->viewMode() == QListView::IconMode)
     {
@@ -527,7 +686,7 @@ void ColorPaletteWidget::updateItemColor(int itemIndex, QColor newColor)
         swatchPainter.setPen(borderShadow);
         swatchPainter.drawRect(0, 0, mIconSize.width() - 1, mIconSize.height() - 1);
     }
-    swatchIcon.addPixmap(colourSwatch, QIcon::Selected);
+    swatchIcon.addPixmap(colorSwatch, QIcon::Selected);
 
     ui->colorListWidget->item(itemIndex)->setIcon(swatchIcon);
 
