@@ -18,6 +18,7 @@ GNU General Public License for more details.
 #include "importexportdialog.h"
 #include "ui_importexportdialog.h"
 #include <QFileInfo>
+#include <QDialogButtonBox>
 
 ImportExportDialog::ImportExportDialog(QWidget* parent, Mode eMode, FileType eFileType) : QDialog(parent)
 {
@@ -26,8 +27,8 @@ ImportExportDialog::ImportExportDialog(QWidget* parent, Mode eMode, FileType eFi
 
     ui = new Ui::ImportExportDialog;
     ui->setupUi(this);
+    hidePreviewGroupBox(true);
     m_fileDialog = new FileDialog(this);
-
     connect(ui->browseButton, &QPushButton::clicked, this, &ImportExportDialog::browse);
 
     Qt::WindowFlags eFlags = Qt::Dialog | Qt::WindowTitleHint | Qt::WindowCloseButtonHint;
@@ -39,6 +40,12 @@ ImportExportDialog::~ImportExportDialog()
     delete ui;
 }
 
+QDialogButtonBox* ImportExportDialog::getDialogButtonBox()
+{
+    return ui->buttonBox;
+}
+
+
 QString ImportExportDialog::getFilePath() const
 {
     return m_filePaths.isEmpty() ? QString() : m_filePaths.first();
@@ -55,6 +62,16 @@ QString ImportExportDialog::getAbsolutePath()
     return info.absolutePath();
 }
 
+void ImportExportDialog::hideInstructionsLabel(bool hide)
+{
+    ui->instructionsLabel->setHidden(hide);
+}
+
+void ImportExportDialog::setInstructionsLabel(const QString& text)
+{
+    ui->instructionsLabel->setText(text);
+}
+
 void ImportExportDialog::init()
 {
     switch (mMode)
@@ -78,6 +95,21 @@ QGroupBox* ImportExportDialog::getOptionsGroupBox()
     return ui->optionsGroupBox;
 }
 
+void ImportExportDialog::hideOptionsGroupBox(bool hide)
+{
+    ui->optionsGroupBox->setHidden(hide);
+}
+
+void ImportExportDialog::hidePreviewGroupBox(bool hide)
+{
+    ui->previewGroupBox->setHidden(hide);
+}
+
+QGroupBox* ImportExportDialog::getPreviewGroupBox()
+{
+    return ui->previewGroupBox;
+}
+
 void ImportExportDialog::setFileExtension(QString extension)
 {
     for (int i = 0; i < m_filePaths.size(); i++)
