@@ -26,6 +26,8 @@ namespace Ui {
 class ImportExportDialog;
 }
 
+class QDialogButtonBox;
+
 class ImportExportDialog : public QDialog
 {
     Q_OBJECT
@@ -40,16 +42,26 @@ public:
     QString getFilePath() const;
     QString getAbsolutePath();
     QStringList getFilePaths();
+    int getPosIndex() { return mPosIndex; }
 
 signals:
     void filePathsChanged(QStringList filePaths);
 
 protected:
     QGroupBox* getOptionsGroupBox();
+    QGroupBox* getPreviewGroupBox();
+    QDialogButtonBox* getDialogButtonBox();
+
     void setFileExtension(QString extension);
+    void hideOptionsGroupBox(bool hide);
+    void hidePreviewGroupBox(bool hide);
+    void hideInstructionsLabel(bool hide);
+
+    void setInstructionsLabel(const QString& text);
 
 private slots:
     void browse();
+    void setPosIndex(int index) { mPosIndex = index; }
 
 private:
     Ui::ImportExportDialog* ui = nullptr;
@@ -59,6 +71,7 @@ private:
 
     FileType mFileType = FileType::ANIMATION;
     Mode mMode = Import;
+    int mPosIndex = 0;
 };
 
 #endif // IMPORTEXPORTDIALOG_H
