@@ -30,7 +30,7 @@ GNU General Public License for more details.
 #include "layermanager.h"
 #include "layercamera.h"
 #include "platformhandler.h"
-
+#include "log.h"
 
 void installTranslator(PencilApplication& app)
 {
@@ -40,6 +40,7 @@ void installTranslator(PencilApplication& app)
     {
         strUserLocale = QLocale::system().name();
     }
+    QLocale::setDefault(QLocale(strUserLocale));
 
     strUserLocale.replace("-", "_");
     QTranslator* qtTranslator = new QTranslator(&app);
@@ -314,17 +315,16 @@ int handleArguments(PencilApplication& app)
 
 int main(int argc, char* argv[])
 {
-
     // iss #940
     // Force dot separator on numbers because some localizations
     // uses comma as separator.
     std::setlocale(LC_NUMERIC, "en_US.UTF-8");
+
     Q_INIT_RESOURCE(core_lib);
 
+    PlatformHandler::initialise();
+
     QSettings settings(PENCIL2D, PENCIL2D);
-#ifdef Q_OS_MACOS
-    QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
     if (settings.value("EnableHighDpiScaling", "true").toBool())
     {
         // Enable auto screen scaling on high dpi display, for example, a 4k monitor
@@ -333,6 +333,8 @@ int main(int argc, char* argv[])
         PencilApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     }
 
+    initCategoryLogging();
+
     PencilApplication app(argc, argv);
 
     installTranslator(app);
