@@ -15,6 +15,8 @@ GNU General Public License for more details.
 
 */
 
+#include <QLayout>
+#include <QResizeEvent>
 
 #include "basedockwidget.h"
 #include "platformhandler.h"
@@ -38,3 +40,26 @@ BaseDockWidget::BaseDockWidget(QWidget* pParent)
 BaseDockWidget::~BaseDockWidget()
 {
 }
+
+void BaseDockWidget::resizeEvent(QResizeEvent *event)
+{
+    QDockWidget::resizeEvent(event);
+
+    // Not sure where the -2 comes from, but the event width is always 2 more than what is passed to FlowLayout::setGeometry
+    int minHeight = getMinHeightForWidth(event->size().width() - 2);
+
+    if (minHeight < 0) return;
+
+#ifdef __APPLE__
+    // For some reason the behavior of minimumSize and the margin changes on mac when floating, so we need to do this
+#else
+    minHeight += layout()->margin()*2;
+#endif
+    setMinimumSize(QSize(layout()->minimumSize().width(), minHeight));
+}
+
+int BaseDockWidget::getMinHeightForWidth(int width)
+{
+    Q_UNUSED(width)
+    return -1;
+}
