@@ -48,7 +48,9 @@
 **
 ****************************************************************************/
 
-#include <QtWidgets>
+#include <QWidget>
+#include <QLayout>
+#include <QtMath>
 
 #include "flowlayout.h"
 //! [1]
@@ -124,7 +126,7 @@ QLayoutItem *FlowLayout::takeAt(int index)
 //! [6]
 Qt::Orientations FlowLayout::expandingDirections() const
 {
-    return nullptr;
+    return 0;
 }
 //! [6]
 
@@ -174,13 +176,16 @@ int FlowLayout::doLayout(const QRect &rect, bool testOnly) const
     int x = effectiveRect.x();
     int y = effectiveRect.y();
     int lineHeight = 0;
+    int rowCount = 0;
 //! [9]
 
 //! [10]
     QLayoutItem *item;
-    foreach (item, itemList) {
+    int spaceX = 0;
+    for (int i = 0; i < itemList.length(); i++) {
+        item = itemList.at(i);
         QWidget *wid = item->widget();
-        int spaceX = horizontalSpacing();
+        spaceX = horizontalSpacing();
         if (spaceX == -1)
             spaceX = wid->style()->layoutSpacing(
                 QSizePolicy::PushButton, QSizePolicy::PushButton, Qt::Horizontal);
@@ -192,18 +197,38 @@ int FlowLayout::doLayout(const QRect &rect, bool testOnly) const
 //! [11]
         int nextX = x + item->sizeHint().width() + spaceX;
         if (nextX - spaceX > effectiveRect.right() && lineHeight > 0) {
+            if(!testOnly && alignment() & Qt::AlignHCenter) {
+                int offset = qFloor((effectiveRect.right() + spaceX - x) / 2);
+                for(int j = i-1; j > i-1-rowCount; j--) {
+                    auto rowItem = itemList.at(j);
+                    rowItem->setGeometry(rowItem->geometry().adjusted(offset, 0, offset, 0));
+                }
+            }
+
             x = effectiveRect.x();
             y = y + lineHeight + spaceY;
             nextX = x + item->sizeHint().width() + spaceX;
             lineHeight = 0;
+            rowCount = 0;
         }
+        rowCount++;
 
-        if (!testOnly)
+        if (!testOnly) {
             item->setGeometry(QRect(QPoint(x, y), item->sizeHint()));
+        }
 
         x = nextX;
         lineHeight = qMax(lineHeight, item->sizeHint().height());
     }
+
+    if (!testOnly && alignment() & Qt::AlignHCenter) {
+        int offset = qFloor((effectiveRect.right() + spaceX - x) / 2);
+        for (int j = itemList.length()-1; j > itemList.length()-1-rowCount; j--) {
+            auto rowItem = itemList.at(j);
+            rowItem->setGeometry(rowItem->geometry().adjusted(offset, 0, offset, 0));
+        }
+    }
+
     return y + lineHeight - rect.y() + bottom;
 }
 //! [11]
