@@ -69,6 +69,9 @@ public:
     int animationLength(bool includeSounds = true);
     void notifyAnimationLengthChanged();
 
+    QString nameSuggestLayer(const QString& name);
+    int getLastLayerIndex() { return count() - 1; }
+
 Q_SIGNALS:
     void currentLayerChanged(int index);
     void layerCountChanged(int count);
