@@ -46,8 +46,15 @@ bool PlaybackManager::init()
     mFlipTimer = new QTimer(this);
     mFlipTimer->setTimerType(Qt::PreciseTimer);
 
+    mScrubTimer = new QTimer(this);
+    mScrubTimer->setTimerType(Qt::PreciseTimer);
+    mSoundclipsToPLay.clear();
+
     QSettings settings (PENCIL2D, PENCIL2D);
     mFps = settings.value(SETTING_FPS).toInt();
+    mMsecSoundScrub = settings.value(SETTING_SOUND_SCRUB_MSEC).toInt();
+    if (mMsecSoundScrub == 0) { mMsecSoundScrub = 100; }
+    mSoundScrub = settings.value(SETTING_SOUND_SCRUB_ACTIVE).toBool();
 
     mElapsedTimer = new QElapsedTimer;
     connect(mTimer, &QTimer::timeout, this, &PlaybackManager::timerTick);
@@ -79,6 +86,7 @@ Status PlaybackManager::save(Object* o)
     data->setMarkInFrameNumber(mMarkInFrame);
     data->setMarkOutFrameNumber(mMarkOutFrame);
     data->setFrameRate(mFps);
+    data->setCurrentFrame(editor()->currentFrame());
     return Status::OK;
 }
 
@@ -101,37 +109,13 @@ void PlaybackManager::play()
     if (frame >= mEndFrame || frame < mStartFrame)
     {
         editor()->scrubTo(mStartFrame);
+        frame = editor()->currentFrame();
     }
 
-    // get keyframe from layer
-    KeyFrame* key = nullptr;
-    if (!mListOfActiveSoundFrames.isEmpty())
-    {
-        for (int i = 0; i < object()->getLayerCount(); ++i)
-        {
-            Layer* layer = object()->getLayer(i);
-            if (layer->type() == Layer::SOUND)
-            {
-                key = layer->getKeyFrameWhichCovers(frame);
-            }
-        }
-    }
-
-    // check list content before playing
-    for (int pos = 0; pos < mListOfActiveSoundFrames.count(); pos++)
-    {
-        if (key != nullptr)
-        {
-            if (key->pos() + key->length() >= frame)
-            {
-                mListOfActiveSoundFrames.takeLast();
-            }
-        }
-        else if (frame < mListOfActiveSoundFrames.at(pos))
-        {
-            mListOfActiveSoundFrames.clear();
-        }
-    }
+    mListOfActiveSoundFrames.clear();
+    // Check for any sounds we should start playing part-way through.
+    mCheckForSoundsHalfway = true;
+    playSounds(frame);
 
     mTimer->setInterval(static_cast<int>(1000.f / mFps));
     mTimer->start();
@@ -140,9 +124,6 @@ void PlaybackManager::play()
     mPlayingFrameCounter = 1;
     mElapsedTimer->start();
 
-    // Check for any sounds we should start playing part-way through.
-    mCheckForSoundsHalfway = true;
-
     emit playStateChanged(true);
 }
 
@@ -219,6 +200,34 @@ void PlaybackManager::playFlipInBetween()
     emit playStateChanged(true);
 }
 
+void PlaybackManager::playScrub(int frame)
+{
+    if (!mSoundScrub || !mSoundclipsToPLay.isEmpty()) {return; }
+
+    auto layerMan = editor()->layers();
+    for (int i = 0; i < layerMan->count(); i++)
+    {
+        Layer* layer = layerMan->getLayer(i);
+        if (layer->type() == Layer::SOUND && layer->visible())
+        {
+            KeyFrame* key = layer->getKeyFrameWhichCovers(frame);
+            if (key != nullptr)
+            {
+                SoundClip* clip = static_cast<SoundClip*>(key);
+                mSoundclipsToPLay.append(clip);
+            }
+        }
+    }
+
+    if (mSoundclipsToPLay.isEmpty()) { return; }
+
+    mScrubTimer->singleShot(mMsecSoundScrub, this, &PlaybackManager::stopScrubPlayback);
+    for (int i = 0; i < mSoundclipsToPLay.count(); i++)
+    {
+        mSoundclipsToPLay.at(i)->playFromPosition(frame, mFps);
+    }
+}
+
 void PlaybackManager::setFps(int fps)
 {
     if (mFps != fps)
@@ -337,14 +346,14 @@ bool PlaybackManager::skipFrame()
     //float expectedTime = (mPlayingFrameCounter) * (1000.f / mFps);
     //qDebug("Expected:  %.2f ms", expectedTime);
     //qDebug("Actual:    %d   ms", mElapsedTimer->elapsed());
-    
+
     int t = qRound((mPlayingFrameCounter - 1) * (1000.f / mFps));
     if (mElapsedTimer->elapsed() < t)
     {
         qDebug() << "skip";
         return true;
     }
-    
+
     ++mPlayingFrameCounter;
     return false;
 }
@@ -372,10 +381,18 @@ void PlaybackManager::stopSounds()
     }
 }
 
+void PlaybackManager::stopScrubPlayback()
+{
+    for (int i = 0; i < mSoundclipsToPLay.count(); i++)
+    {
+        mSoundclipsToPLay.at(i)->pause();
+    }
+    mSoundclipsToPLay.clear();
+}
+
 void PlaybackManager::timerTick()
 {
     int currentFrame = editor()->currentFrame();
-    playSounds(currentFrame);
 
     // reach the end
     if (currentFrame >= mEndFrame)
@@ -395,8 +412,11 @@ void PlaybackManager::timerTick()
     if (skipFrame())
         return;
 
-    // keep going 
+    // keep going
     editor()->scrubForward();
+
+    int newFrame = editor()->currentFrame();
+    playSounds(newFrame);
 }
 
 void PlaybackManager::flipTimerTick()
