@@ -24,6 +24,7 @@ GNU General Public License for more details.
 #include "layersound.h"
 #include "soundclip.h"
 #include "soundplayer.h"
+#include "layermanager.h"
 
 SoundManager::SoundManager(Editor* editor) : BaseManager(editor)
 {
@@ -145,6 +146,8 @@ Status SoundManager::loadSound(SoundClip* soundClip, QString strSoundFile)
         return st;
     }
 
+    editor()->layers()->notifyAnimationLengthChanged();
+
     return Status::OK;
 }
 
@@ -176,6 +179,8 @@ void SoundManager::onDurationChanged(SoundPlayer* player, int64_t duration)
     clip->setLength(static_cast<int>(frameLength));
     clip->setDuration(duration);
 
+    editor()->layers()->notifyAnimationLengthChanged();
+
     emit soundClipDurationChanged();
 }
 
