@@ -32,6 +32,7 @@ class ViewManager : public BaseManager
 
 public:
     explicit ViewManager(Editor* editor);
+    ~ViewManager() override;
 
     bool init() override;
     Status load(Object*) override;
@@ -48,6 +49,9 @@ public:
     QRectF mapCanvasToScreen(const QRectF& rect);
     QRectF mapScreenToCanvas(const QRectF& rect);
 
+    QPolygonF mapPolygonToScreen(const QPolygonF& polygon);
+    QPolygonF mapPolygonToCanvas(const QPolygonF& polygon);
+
     QPainterPath mapCanvasToScreen(const QPainterPath& path);
     QPainterPath mapScreenToCanvas(const QPainterPath& path);
 
@@ -72,13 +76,28 @@ public:
 
     void flipHorizontal(bool b);
     void flipVertical(bool b);
+    void setOverlayCenter(bool b);
+    void setOverlayThirds(bool b);
+    void setOverlayGoldenRatio(bool b);
+    void setOverlaySafeAreas(bool b);
 
     bool isFlipHorizontal() { return mIsFlipHorizontal; }
     bool isFlipVertical() { return mIsFlipVertical; }
+    bool getOverlayCenter() { return mOverlayCenter; }
+    bool getOverlayThirds() { return mOverlayThirds; }
+    bool getOverlayGoldenRatio() { return mOverlayGoldenRatio; }
+    bool getOverlaySafeAreas() { return mOverlaySafeAreas; }
+
 
     void setCanvasSize(QSize size);
     void setCameraLayer(Layer* layer);
 
+    QTransform getImportView() { return mImportView; }
+    void setImportView(const QTransform& newView) { mImportView = newView; }
+
+    void setImportFollowsCamera(bool b) { mImportFollowsCamera = b; }
+    bool getImportFollowsCamera() { return mImportFollowsCamera; }
+
     void updateViewTransforms();
 
     Q_SIGNAL void viewChanged();
@@ -93,6 +112,7 @@ private:
     QTransform mViewCanvas;
     QTransform mViewCanvasInverse;
     QTransform mCentre;
+    QTransform mImportView;
 
     Camera* mDefaultEditorCamera = nullptr;
     Camera* mCurrentCamera = nullptr;
@@ -101,6 +121,12 @@ private:
 
     bool mIsFlipHorizontal = false;
     bool mIsFlipVertical = false;
+    bool mOverlayCenter = false;
+    bool mOverlayThirds = false;
+    bool mOverlayGoldenRatio = false;
+    bool mOverlaySafeAreas = false;
+
+    bool mImportFollowsCamera = false;
 
     LayerCamera* mCameraLayer = nullptr;
 };
