@@ -18,6 +18,8 @@ GNU General Public License for more details.
 
 #include <QDebug>
 #include <QSettings>
+#include <QPainter>
+#include <QDomElement>
 #include "keyframe.h"
 #include "object.h"
 #include "timelinecells.h"
@@ -99,6 +101,13 @@ int Layer::getPreviousKeyFramePosition(int position) const
 
 int Layer::getNextKeyFramePosition(int position) const
 {
+    // workaround: bug with lower_bound?
+    // when position is before the first frame it == mKeyFrames.end() for some reason
+    if (position < firstKeyFramePosition())
+    {
+       return firstKeyFramePosition();
+    }
+
     auto it = mKeyFrames.lower_bound(position);
     if (it == mKeyFrames.end())
     {
@@ -121,7 +130,7 @@ int Layer::getPreviousFrameNumber(int position, bool isAbsolute) const
     else
         prevNumber = position - 1;
 
-    if (prevNumber == position)
+    if (prevNumber >= position)
     {
         return -1; // There is no previous keyframe
     }
@@ -137,7 +146,7 @@ int Layer::getNextFrameNumber(int position, bool isAbsolute) const
     else
         nextNumber = position + 1;
 
-    if (nextNumber == position)
+    if (nextNumber <= position)
         return -1; // There is no next keyframe
 
     return nextNumber;
@@ -316,22 +325,36 @@ void Layer::paintTrack(QPainter& painter, TimeLineCells* cells,
     if (mVisible)
     {
         QColor col;
-        if (type() == BITMAP) col = QColor(151, 176, 244);
-        if (type() == VECTOR) col = QColor(150, 242, 150);
-        if (type() == SOUND) col = QColor(237, 147, 147, 100);
-        if (type() == CAMERA) col = QColor(239, 232, 148);
+        if (type() == BITMAP) col = QColor(51, 155, 252);
+        if (type() == VECTOR) col = QColor(70, 205, 123);
+        if (type() == SOUND) col = QColor(255, 141, 112);
+        if (type() == CAMERA) col = QColor(253, 202, 92);
 
+        painter.save();
         painter.setBrush(col);
         painter.setPen(QPen(QBrush(QColor(100, 100, 100)), 1, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin));
         painter.drawRect(x, y - 1, width, height);
 
-        paintFrames(painter, cells, y, height, selected, frameSize);
-
         // changes the apparence if selected
         if (selected)
         {
             paintSelection(painter, x, y, width, height);
         }
+        else
+        {
+            painter.save();
+            QLinearGradient linearGrad(QPointF(0, y), QPointF(0, y + height));
+            linearGrad.setColorAt(0, QColor(255,255,255,150));
+            linearGrad.setColorAt(1, QColor(0,0,0,0));
+            painter.setCompositionMode(QPainter::CompositionMode_Overlay);
+            painter.setBrush(linearGrad);
+            painter.drawRect(x, y - 1, width, height);
+            painter.restore();
+        }
+
+        paintFrames(painter, col, cells, y, height, selected, frameSize);
+
+        painter.restore();
     }
     else
     {
@@ -341,7 +364,7 @@ void Layer::paintTrack(QPainter& painter, TimeLineCells* cells,
     }
 }
 
-void Layer::paintFrames(QPainter& painter, TimeLineCells* cells, int y, int height, bool selected, int frameSize)
+void Layer::paintFrames(QPainter& painter, QColor trackCol, TimeLineCells* cells, int y, int height, bool selected, int frameSize)
 {
     painter.setPen(QPen(QBrush(QColor(40, 40, 40)), 1, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin));
 
@@ -362,13 +385,19 @@ void Layer::paintFrames(QPainter& painter, TimeLineCells* cells, int y, int heig
             recWidth = frameSize * key->length() - 2;
         }
 
+        if (selected && key->pos() == cells->getCurrentFrame()) {
+            painter.setPen(Qt::white);
+        } else {
+            painter.setPen(QPen(QBrush(QColor(40, 40, 40)), 1, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin));
+        }
+
         if (pair.second->isSelected())
         {
             painter.setBrush(QColor(60, 60, 60));
         }
         else if (selected)
         {
-            painter.setBrush(QColor(60, 60, 60, 120));
+            painter.setBrush(QColor(trackCol.red(), trackCol.green(), trackCol.blue(), 150));
         }
 
         painter.drawRect(recLeft, recTop, recWidth, recHeight);
@@ -377,18 +406,33 @@ void Layer::paintFrames(QPainter& painter, TimeLineCells* cells, int y, int heig
 
 void Layer::paintLabel(QPainter& painter, TimeLineCells* cells,
                        int x, int y, int width, int height,
-                       bool selected, int allLayers)
+                       bool selected, LayerVisibility layerVisibility)
 {
-    Q_UNUSED(cells);
+    Q_UNUSED(cells)
     painter.setBrush(Qt::lightGray);
     painter.setPen(QPen(QBrush(QColor(100, 100, 100)), 1, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin));
     painter.drawRect(x, y - 1, width, height); // empty rectangle  by default
 
+
+    if (selected)
+    {
+        paintSelection(painter, x, y, width, height);
+    } else {
+        painter.save();
+        QLinearGradient linearGrad(QPointF(0, y), QPointF(0, y + height));
+        linearGrad.setColorAt(0, QColor(255,255,255,150));
+        linearGrad.setColorAt(1, QColor(0,0,0,0));
+        painter.setCompositionMode(QPainter::CompositionMode_Overlay);
+        painter.setBrush(linearGrad);
+        painter.drawRect(x, y - 1, width, height);
+        painter.restore();
+    }
+
     if (mVisible)
     {
-        if (allLayers == 0) painter.setBrush(Qt::NoBrush);
-        if (allLayers == 1) painter.setBrush(Qt::darkGray);
-        if ((allLayers == 2) || selected) painter.setBrush(Qt::black);
+        if ((layerVisibility == LayerVisibility::ALL) || selected) painter.setBrush(Qt::black);
+        else if (layerVisibility == LayerVisibility::CURRENTONLY) painter.setBrush(Qt::NoBrush);
+        else if (layerVisibility == LayerVisibility::RELATED) painter.setBrush(Qt::darkGray);
     }
     else
     {
@@ -399,11 +443,6 @@ void Layer::paintLabel(QPainter& painter, TimeLineCells* cells,
     painter.drawEllipse(x + 6, y + 4, 9, 9);
     painter.setRenderHint(QPainter::Antialiasing, false);
 
-    if (selected)
-    {
-        paintSelection(painter, x, y, width, height);
-    }
-
     if (type() == BITMAP) painter.drawPixmap(QPoint(20, y + 2), QPixmap(":/icons/layer-bitmap.png"));
     if (type() == VECTOR) painter.drawPixmap(QPoint(20, y + 2), QPixmap(":/icons/layer-vector.png"));
     if (type() == SOUND) painter.drawPixmap(QPoint(21, y + 2), QPixmap(":/icons/layer-sound.png"));
@@ -418,18 +457,20 @@ void Layer::paintSelection(QPainter& painter, int x, int y, int width, int heigh
     QLinearGradient linearGrad(QPointF(0, y), QPointF(0, y + height));
     QSettings settings(PENCIL2D, PENCIL2D);
     QString style = settings.value("style").toString();
-    linearGrad.setColorAt(0, QColor(255, 255, 255, 128));
-    linearGrad.setColorAt(0.50, QColor(255, 255, 255, 64));
+    linearGrad.setColorAt(0, QColor(0, 0, 0, 255));
     linearGrad.setColorAt(1, QColor(255, 255, 255, 0));
+    painter.save();
+    painter.setCompositionMode(QPainter::CompositionMode_Overlay);
     painter.setBrush(linearGrad);
     painter.setPen(Qt::NoPen);
     painter.drawRect(x, y, width, height - 1);
+    painter.restore();
 }
 
 void Layer::mouseDoubleClick(QMouseEvent* event, int frameNumber)
 {
-    Q_UNUSED(event);
-    Q_UNUSED(frameNumber);
+    Q_UNUSED(event)
+    Q_UNUSED(frameNumber)
 }
 
 void Layer::editProperties()
@@ -659,3 +700,24 @@ KeyFrame* Layer::getKeyFrameWhichCovers(int frameNumber) const
     }
     return nullptr;
 }
+
+QDomElement Layer::createBaseDomElement(QDomDocument& doc)
+{
+    QDomElement layerTag = doc.createElement("layer");
+    layerTag.setAttribute("id", id());
+    layerTag.setAttribute("name", name());
+    layerTag.setAttribute("visibility", visible());
+    layerTag.setAttribute("type", type());
+    return layerTag;
+}
+
+void Layer::loadBaseDomElement(const QDomElement& elem)
+{
+    if (!elem.attribute("id").isNull())
+    {
+        int id = elem.attribute("id").toInt();
+        setId(id);
+    }
+    setName(elem.attribute("name", "untitled"));
+    setVisible(elem.attribute("visibility", "1").toInt());
+}
