@@ -36,6 +36,13 @@ SoundClip::~SoundClip()
     //QFile::remove( fileName() );
 }
 
+SoundClip& SoundClip::operator=(const SoundClip& a) {
+    if (this != &a) {
+        mOriginalSoundClipName = a.mOriginalSoundClipName;
+    }
+    return *this;
+}
+
 SoundClip* SoundClip::clone()
 {
     return new SoundClip(*this);
@@ -94,7 +101,6 @@ void SoundClip::playFromPosition(int frameNumber, int fps)
     }
     qreal msPerFrame = 1000.0 / fps;
     qint64 msIntoSound = qRound(framesIntoSound * msPerFrame);
-
     if (mPlayer)
     {
         mPlayer->setMediaPlayerPosition(msIntoSound);
@@ -102,6 +108,14 @@ void SoundClip::playFromPosition(int frameNumber, int fps)
     }
 }
 
+void SoundClip::pause()
+{
+    if (mPlayer)
+    {
+        mPlayer->pause();
+    }
+}
+
 void SoundClip::stop()
 {
     if (mPlayer)
