@@ -17,15 +17,15 @@ GNU General Public License for more details.
 
 #include "basetool.h"
 
-#include "pointerevent.h"
 #include <array>
 #include <QtMath>
+#include <QPixmap>
 #include "editor.h"
 #include "viewmanager.h"
 #include "toolmanager.h"
 #include "scribblearea.h"
 #include "strokemanager.h"
-
+#include "pointerevent.h"
 
 // ---- shared static variables ---- ( only one instance for all the tools )
 qreal BaseTool::msOriginalPropertyValue;  // start value (width, feather ..)
@@ -240,55 +240,79 @@ QCursor BaseTool::selectMoveCursor(MoveMode mode, ToolType type)
     return QCursor(cursorPixmap);
 }
 
+bool BaseTool::isActive()
+{
+    return strokeManager()->isActive();
+}
+
 /**
  * @brief precision circular cursor: used for drawing stroke size while adjusting
  * @return QPixmap
  */
-QPixmap BaseTool::quickSizeCursor(float brushWidth, float brushFeather, float scalingFac)
+QPixmap BaseTool::quickSizeCursor(qreal scalingFac)
 {
-    float propWidth = qMax(static_cast<float>(0), brushWidth) * scalingFac;
-    float propFeather = qMax(static_cast<float>(0), brushFeather) * scalingFac;
-    float cursorWidth = propWidth + 0.5 * propFeather;
+    qreal propSize = qMax(0., properties.width) * scalingFac;
+    qreal propFeather = qMax(0., properties.feather) * scalingFac;
+    QRectF cursorRect(0, 0, propSize+2, propSize+2);
 
-    if (cursorWidth < 1) { cursorWidth = 1; }
-    float radius = cursorWidth / 2;
-    float xyA = 1 + propFeather / 2;
-    float xyB = 1 + propFeather / 8;
-    float whA = qMax<float>(0, propWidth - xyA - 1);
-    float whB = qMax<float>(0, cursorWidth - propFeather / 4 - 2);
-    QPixmap cursorPixmap = QPixmap(cursorWidth, cursorWidth);
+    QRectF sizeRect = cursorRect.adjusted(1, 1, -1, -1);
+    qreal featherRadius = (1 - propFeather / 100) * propSize / 2.;
+
+    QPixmap cursorPixmap = QPixmap(cursorRect.size().toSize());
     if (!cursorPixmap.isNull())
     {
         cursorPixmap.fill(QColor(255, 255, 255, 0));
         QPainter cursorPainter(&cursorPixmap);
-        cursorPainter.setPen(QColor(0, 0, 0, 255));
-        cursorPainter.drawLine(QPointF(radius - 2, radius), QPointF(radius + 2, radius));
-        cursorPainter.drawLine(QPointF(radius, radius - 2), QPointF(radius, radius + 2));
         cursorPainter.setRenderHints(QPainter::Antialiasing, true);
+
+        // Draw width (outside circle)
+        cursorPainter.setPen(QColor(255, 127, 127, 127));
+        cursorPainter.setBrush(QColor(0, 255, 127, 127));
+        cursorPainter.drawEllipse(sizeRect);
+
+        // Draw feather (inside circle)
+        cursorPainter.setCompositionMode(QPainter::CompositionMode_Darken);
         cursorPainter.setPen(QColor(0, 0, 0, 0));
-        cursorPainter.setBrush(QColor(0, 255, 127, 64));
-        cursorPainter.setCompositionMode(QPainter::CompositionMode_Exclusion);
-        cursorPainter.drawEllipse(QRectF(xyB, xyB, whB, whB)); // outside circle
-        cursorPainter.setBrush(QColor(255, 64, 0, 255));
-        cursorPainter.drawEllipse(QRectF(xyA, xyA, whA, whA)); // inside circle
+        cursorPainter.setBrush(QColor(0, 191, 95, 127));
+        cursorPainter.drawEllipse(cursorRect.center(), featherRadius, featherRadius);
+
+        // Draw cursor in center
+        cursorPainter.setRenderHints(QPainter::Antialiasing, false);
+        cursorPainter.setPen(QColor(0, 0, 0, 255));
+        cursorPainter.drawLine(cursorRect.center() - QPoint(2, 0), cursorRect.center() + QPoint(2, 0));
+        cursorPainter.drawLine(cursorRect.center() - QPoint(0, 2), cursorRect.center() + QPoint(0, 2));
+
         cursorPainter.end();
     }
     return cursorPixmap;
 }
 
-void BaseTool::startAdjusting(ToolPropertyType propertyType, qreal step)
+bool BaseTool::startAdjusting(Qt::KeyboardModifiers modifiers, qreal step)
 {
-    msIsAdjusting = true;
-    mAdjustmentStep = step;
-    if (propertyType == WIDTH)
+    if (mQuickSizingProperties.contains(modifiers))
     {
-        msOriginalPropertyValue = properties.width;
+        switch (mQuickSizingProperties.value(modifiers)) {
+        case WIDTH:
+            msOriginalPropertyValue = properties.width;
+            break;
+        case FEATHER:
+            msOriginalPropertyValue = properties.feather;
+            break;
+        case TOLERANCE:
+            msOriginalPropertyValue = properties.tolerance;
+            break;
+        default:
+            qDebug() << "Unhandled quick sizing property for tool" << typeName();
+            Q_ASSERT(false);
+            return false;
+        }
+
+        msIsAdjusting = true;
+        mAdjustmentStep = step;
+        mScribbleArea->updateCanvasCursor();
+        return true;
     }
-    else if (propertyType == FEATHER)
-    {
-        msOriginalPropertyValue = properties.feather;
-    }
-    mScribbleArea->updateCanvasCursor();
+    return false;
 }
 
 void BaseTool::stopAdjusting()
@@ -299,15 +323,10 @@ void BaseTool::stopAdjusting()
     mEditor->getScribbleArea()->updateCanvasCursor();
 }
 
-void BaseTool::adjustCursor(qreal argOffsetX, Qt::KeyboardModifiers keyMod) //offsetx x-lastx ...
+void BaseTool::adjustCursor(Qt::KeyboardModifiers modifiers)
 {
-    ToolPropertyType propertyType;
-    propertyType = (keyMod & Qt::ControlModifier) ? FEATHER : WIDTH;
-
     qreal inc = qPow(msOriginalPropertyValue * 100, 0.5);
-    qreal newValue = inc + argOffsetX;
-    int max = (propertyType == FEATHER) ? 200 : 200;
-    int min = (propertyType == FEATHER) ? 2 : 1;
+    qreal newValue = inc + getCurrentPoint().x();
 
     if (newValue < 0)
     {
@@ -320,27 +339,21 @@ void BaseTool::adjustCursor(qreal argOffsetX, Qt::KeyboardModifiers keyMod) //of
         int tempValue = (int)(newValue / mAdjustmentStep); // + 0.5 ?
         newValue = tempValue * mAdjustmentStep;
     }
-    if (newValue < min) // can be optimized for size: min(200,max(0.2,newValueX))
-    {
-        newValue = min;
-    }
-    else if (newValue > max)
-    {
-        newValue = max;
-    }
 
-    switch (propertyType)
+    switch (mQuickSizingProperties.value(modifiers))
     {
-    case FEATHER:
-        if ((type() == BRUSH) || (type() == ERASER) || (this->type() == SMUDGE))
-        {
-            mEditor->tools()->setFeather(newValue);
-        }
-        break;
     case WIDTH:
-        mEditor->tools()->setWidth(newValue);
+        mEditor->tools()->setWidth(qBound(1., newValue, 200.));
+        break;
+    case FEATHER:
+        mEditor->tools()->setFeather(qBound(2., newValue, 200.));
+        break;
+    case TOLERANCE:
+        mEditor->tools()->setTolerance(qBound(0., newValue, 100.));
         break;
     default:
+        qDebug() << "Unhandled quick sizing property for tool" << typeName();
+        Q_ASSERT(false);
         break;
     };
 }
