@@ -22,11 +22,11 @@ GNU General Public License for more details.
 #include <QString>
 #include <QCursor>
 #include <QPointF>
-#include <QPixmap>
 #include <QHash>
 #include "movemode.h"
 #include "pencildef.h"
 
+class QPixmap;
 class Editor;
 class ScribbleArea;
 class QKeyEvent;
@@ -83,18 +83,27 @@ public:
     virtual bool keyReleaseEvent(QKeyEvent*) { return false; }
 
     // dynamic cursor adjustment
-    virtual void startAdjusting(ToolPropertyType argSettingType, qreal argStep);
+    virtual bool startAdjusting(Qt::KeyboardModifiers modifiers, qreal argStep);
     virtual void stopAdjusting();
-    virtual void adjustCursor(qreal argOffsetX, Qt::KeyboardModifiers keyMod);
+    virtual void adjustCursor(Qt::KeyboardModifiers modifiers);
 
     virtual void clearToolData() {}
     virtual void resetToDefault() {}
 
     static QPixmap canvasCursor(float brushWidth, float brushFeather, bool useFeather, float scalingFac, int windowWidth);
-    static QPixmap quickSizeCursor(float brushWidth, float brushFeather, float scalingFac);
+    QPixmap quickSizeCursor(qreal scalingFac);
     static QCursor selectMoveCursor(MoveMode mode, ToolType type);
     static bool isAdjusting() { return msIsAdjusting; }
 
+    /** Check if the tool is active.
+     *
+     *  An active tool is definied as one which is actively modifying the buffer.
+     *  This is used to check if an full frame cache can be used instead of redrawing with CanvasPainter.
+     *
+     * @return Returns true if the tool is currently active, else returns false.
+     */
+    virtual bool isActive();
+
     virtual void setWidth(const qreal width);
     virtual void setFeather(const qreal feather);
     virtual void setInvisibility(const bool invisibility);
@@ -134,6 +143,8 @@ protected:
     Editor* mEditor = nullptr;
     ScribbleArea* mScribbleArea = nullptr;
 
+    QHash<Qt::KeyboardModifiers, ToolPropertyType> mQuickSizingProperties;
+
 private:
     StrokeManager* mStrokeManager = nullptr;
     qreal mAdjustmentStep = 0.0f;
