@@ -21,6 +21,7 @@ GNU General Public License for more details.
 #include <QSettings>
 #include <QPixmap>
 #include <QPainter>
+#include <QColor>
 
 #include "beziercurve.h"
 #include "vectorimage.h"
@@ -30,6 +31,7 @@ GNU General Public License for more details.
 #include "strokemanager.h"
 #include "layermanager.h"
 #include "viewmanager.h"
+#include "selectionmanager.h"
 #include "scribblearea.h"
 #include "blitrect.h"
 #include "pointerevent.h"
@@ -48,26 +50,25 @@ void BrushTool::loadSettings()
 {
     mPropertyEnabled[WIDTH] = true;
     mPropertyEnabled[FEATHER] = true;
-    mPropertyEnabled[USEFEATHER] = true;
     mPropertyEnabled[PRESSURE] = true;
     mPropertyEnabled[INVISIBILITY] = true;
     mPropertyEnabled[STABILIZATION] = true;
-    mPropertyEnabled[ANTI_ALIASING] = true;
 
     QSettings settings(PENCIL2D, PENCIL2D);
 
     properties.width = settings.value("brushWidth", 24.0).toDouble();
     properties.feather = settings.value("brushFeather", 48.0).toDouble();
-    properties.useFeather = settings.value("brushUseFeather", true).toBool();
     properties.pressure = settings.value("brushPressure", true).toBool();
     properties.invisibility = settings.value("brushInvisibility", false).toBool();
     properties.preserveAlpha = OFF;
     properties.stabilizerLevel = settings.value("brushLineStabilization", StabilizationLevel::STRONG).toInt();
-    properties.useAA = settings.value("brushAA", 1).toInt();
+    properties.useAA = DISABLED;
 
-    if (properties.useFeather == true) { properties.useAA = -1; }
     if (properties.width <= 0) { setWidth(15); }
     if (std::isnan(properties.feather)) { setFeather(15); }
+
+    mQuickSizingProperties.insert(Qt::ShiftModifier, WIDTH);
+    mQuickSizingProperties.insert(Qt::ControlModifier, FEATHER);
 }
 
 void BrushTool::resetToDefault()
@@ -75,7 +76,6 @@ void BrushTool::resetToDefault()
     setWidth(24.0);
     setFeather(48.0);
     setStabilizerLevel(StabilizationLevel::STRONG);
-    setUseFeather(true);
 }
 
 void BrushTool::setWidth(const qreal width)
@@ -89,17 +89,6 @@ void BrushTool::setWidth(const qreal width)
     settings.sync();
 }
 
-void BrushTool::setUseFeather(const bool usingFeather)
-{
-    // Set current property
-    properties.useFeather = usingFeather;
-
-    // Update settings
-    QSettings settings(PENCIL2D, PENCIL2D);
-    settings.setValue("brushUseFeather", usingFeather);
-    settings.sync();
-}
-
 void BrushTool::setFeather(const qreal feather)
 {
     // Set current property
@@ -141,17 +130,6 @@ void BrushTool::setStabilizerLevel(const int level)
     settings.sync();
 }
 
-void BrushTool::setAA(const int AA)
-{
-    // Set current property
-    properties.useAA = AA;
-
-    // Update settings
-    QSettings settings(PENCIL2D, PENCIL2D);
-    settings.setValue("brushAA", AA);
-    settings.sync();
-}
-
 QCursor BrushTool::cursor()
 {
     if (mEditor->preference()->isOn(SETTING::TOOL_CURSOR))
@@ -222,8 +200,7 @@ void BrushTool::paintAt(QPointF point)
                                  properties.feather,
                                  mEditor->color()->frontColor(),
                                  opacity,
-                                 properties.useFeather,
-                                 properties.useAA);
+                                 true);
 
         int rad = qRound(brushWidth) / 2 + 2;
         mScribbleArea->refreshBitmap(rect, rad);
@@ -270,8 +247,7 @@ void BrushTool::drawStroke()
                                      properties.feather,
                                      mEditor->color()->frontColor(),
                                      opacity,
-                                     properties.useFeather,
-                                     properties.useAA);
+                                     true);
             if (i == (steps - 1))
             {
                 mLastBrushPoint = getCurrentPoint();
@@ -351,14 +327,14 @@ void BrushTool::paintVectorStroke()
         curve.setFilled(false);
         curve.setInvisibility(properties.invisibility);
         curve.setVariableWidth(properties.pressure);
-        curve.setColourNumber(mEditor->color()->frontColorNumber());
+        curve.setColorNumber(mEditor->color()->frontColorNumber());
 
         VectorImage* vectorImage = static_cast<VectorImage*>(layer->getLastKeyFrameAtPosition(mEditor->currentFrame()));
         vectorImage->addCurve(curve, mEditor->view()->scaling(), false);
 
-        if (vectorImage->isAnyCurveSelected() || mScribbleArea->isSomethingSelected())
+        if (vectorImage->isAnyCurveSelected() || mEditor->select()->somethingSelected())
         {
-            mScribbleArea->deselectAll();
+            mEditor->deselectAll();
         }
 
         vectorImage->setSelected(vectorImage->getLastCurveNumber(), true);
