@@ -19,6 +19,7 @@ GNU General Public License for more details.
 #define BRUSHTOOL_H
 
 #include "stroketool.h"
+#include <QColor>
 
 
 class BrushTool : public StrokeTool
@@ -43,10 +44,8 @@ public:
 
     void setWidth(const qreal width) override;
     void setFeather(const qreal feather) override;
-    void setUseFeather(const bool usingFeather) override;
     void setPressure(const bool pressure) override;
     void setInvisibility(const bool invisibility) override;
-    void setAA(const int useAA) override;
     void setStabilizerLevel(const int level) override;
 
 protected:
