@@ -25,24 +25,26 @@ class EraserTool : public StrokeTool
     Q_OBJECT
 
 public:
-    explicit EraserTool( QObject* parent = 0 );
+    explicit EraserTool(QObject* parent = nullptr);
     ToolType type() override;
     void loadSettings() override;
     void resetToDefault() override;
     QCursor cursor() override;
 
-    void pointerMoveEvent( PointerEvent* ) override;
-    void pointerPressEvent( PointerEvent* ) override;
-    void pointerReleaseEvent( PointerEvent* ) override;
+    void pointerMoveEvent(PointerEvent*) override;
+    void pointerPressEvent(PointerEvent*) override;
+    void pointerReleaseEvent(PointerEvent*) override;
 
     void drawStroke();
-    void paintAt( QPointF point );
+    void paintAt(QPointF point);
     void removeVectorPaint();
     void updateStrokes();
 
-    void setWidth( const qreal width ) override;
-    void setFeather( const qreal feather ) override;
-    void setPressure( const bool pressure ) override;
+    void setWidth(const qreal width) override;
+    void setFeather(const qreal feather) override;
+    void setUseFeather(const bool usingFeather) override;
+    void setPressure(const bool pressure) override;
+    void setAA(const int aa) override;
     void setStabilizerLevel(const int level) override;
 
 protected:
