@@ -1,4 +1,4 @@
-/*
+﻿/*
 
 Pencil - Traditional Animation Software
 Copyright (C) 2005-2007 Patrick Corrieri & Pascal Naidon
@@ -30,7 +30,7 @@ GNU General Public License for more details.
 #include "editor.h"
 #include "layermanager.h"
 #include "scribblearea.h"
-
+#include "util.h"
 
 EyedropperTool::EyedropperTool(QObject* parent) : BaseTool(parent)
 {
@@ -56,7 +56,7 @@ QCursor EyedropperTool::cursor()
     }
 }
 
-QCursor EyedropperTool::cursor(const QColor colour)
+QCursor EyedropperTool::cursor(const QColor color)
 {
     QPixmap icon(":icons/eyedropper.png");
 
@@ -66,7 +66,7 @@ QCursor EyedropperTool::cursor(const QColor colour)
     QPainter painter(&pixmap);
     painter.drawPixmap(0, 0, icon);
     painter.setPen(QPen(Qt::black, 1, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin));
-    painter.setBrush(colour);
+    painter.setBrush(color);
     painter.drawRect(16, 16, 15, 15);
     painter.end();
 
@@ -79,29 +79,14 @@ void EyedropperTool::pointerPressEvent(PointerEvent*)
 void EyedropperTool::pointerMoveEvent(PointerEvent*)
 {
     Layer* layer = mEditor->layers()->currentLayer();
-    if (layer == NULL) { return; }
+    if (layer == nullptr) { return; }
 
     if (layer->type() == Layer::BITMAP)
     {
-        BitmapImage* targetImage = ((LayerBitmap *)layer)->getLastBitmapImageAtFrame(mEditor->currentFrame(), 0);
-        if (targetImage->contains(getCurrentPoint()))
+        QColor pickedColor = getBitmapColor(static_cast<LayerBitmap*>(layer));
+        if (pickedColor.isValid())
         {
-            QColor pickedColour;
-            //pickedColour.setRgba(targetImage->pixel(getCurrentPoint().x(), getCurrentPoint().y()));
-            pickedColour.setRgba(targetImage->pixel(getCurrentPoint().x(), getCurrentPoint().y()));
-            int transp = 255 - pickedColour.alpha();
-            pickedColour.setRed(pickedColour.red() + transp);
-            pickedColour.setGreen(pickedColour.green() + transp);
-            pickedColour.setBlue(pickedColour.blue() + transp);
-
-            if (pickedColour.alpha() != 0)
-            {
-                mScribbleArea->setCursor(cursor(pickedColour));
-            }
-            else
-            {
-                mScribbleArea->setCursor(cursor());
-            }
+            mScribbleArea->setCursor(cursor(pickedColor));
         }
         else
         {
@@ -110,11 +95,10 @@ void EyedropperTool::pointerMoveEvent(PointerEvent*)
     }
     if (layer->type() == Layer::VECTOR)
     {
-        VectorImage* vectorImage = ((LayerVector *)layer)->getLastVectorImageAtFrame(mEditor->currentFrame(), 0);
-        int colourNumber = vectorImage->getColourNumber(getCurrentPoint());
-        if (colourNumber != -1)
+        int pickedColor = getVectorColor(static_cast<LayerVector*>(layer));
+        if (pickedColor >= 0)
         {
-            mScribbleArea->setCursor(cursor(mEditor->object()->getColour(colourNumber).colour));
+            mScribbleArea->setCursor(cursor(mEditor->object()->getColor(pickedColor).color));
         }
         else
         {
@@ -127,7 +111,6 @@ void EyedropperTool::pointerReleaseEvent(PointerEvent* event)
 {
     if (event->button() == Qt::LeftButton)
     {
-        qDebug() << "was left button or tablet button";
         updateFrontColor();
 
         // reset cursor
@@ -141,25 +124,49 @@ void EyedropperTool::updateFrontColor()
     if (layer == nullptr) { return; }
     if (layer->type() == Layer::BITMAP)
     {
-        BitmapImage* targetImage = ((LayerBitmap*)layer)->getLastBitmapImageAtFrame(mEditor->currentFrame(), 0);
-        QColor pickedColour;
-        pickedColour.setRgba(targetImage->pixel(getLastPoint().x(), getLastPoint().y()));
-        int transp = 255 - pickedColour.alpha();
-        pickedColour.setRed(pickedColour.red() + transp);
-        pickedColour.setGreen(pickedColour.green() + transp);
-        pickedColour.setBlue(pickedColour.blue() + transp);
-        if (pickedColour.alpha() != 0)
+        QColor pickedColor = getBitmapColor(static_cast<LayerBitmap*>(layer));
+        if (pickedColor.isValid())
         {
-            mEditor->color()->setColor(pickedColour);
+            mEditor->color()->setColor(pickedColor);
         }
     }
     else if (layer->type() == Layer::VECTOR)
     {
-        VectorImage* vectorImage = ((LayerVector*)layer)->getLastVectorImageAtFrame(mEditor->currentFrame(), 0);
-        int colourNumber = vectorImage->getColourNumber(getLastPoint());
-        if (colourNumber != -1)
+        int pickedColor = getVectorColor(static_cast<LayerVector*>(layer));
+        if (pickedColor >= 0)
         {
-            mEditor->color()->setColorNumber(colourNumber);
+            mEditor->color()->setColorNumber(pickedColor);
         }
     }
 }
+
+QColor EyedropperTool::getBitmapColor(LayerBitmap* layer)
+{
+    BitmapImage* targetImage = layer->getLastBitmapImageAtFrame(mEditor->currentFrame(), 0);
+    if (targetImage == nullptr || !targetImage->contains(getLastPoint())) return QColor();
+
+    QColor pickedColour;
+    pickedColour.setRgba(qUnpremultiply(targetImage->pixel(getLastPoint().x(), getLastPoint().y())));
+    if (pickedColour.alpha() <= 0) pickedColour = QColor();
+    return pickedColour;
+}
+
+int EyedropperTool::getVectorColor(LayerVector* layer)
+{
+    auto vectorImage = static_cast<VectorImage*>(layer->getLastKeyFrameAtPosition(mEditor->currentFrame()));
+    if (vectorImage == nullptr) return -1;
+
+    // Check curves
+    const qreal toleranceDistance = 10.0;
+    const QList<int> closestCurves = vectorImage->getCurvesCloseTo(getCurrentPoint(), toleranceDistance);
+    const QList<int> visibleClosestCurves = filter(closestCurves, [vectorImage](int i) { return vectorImage->isCurveVisible(i); });
+
+    if (!visibleClosestCurves.isEmpty())
+    {
+        return vectorImage->getCurvesColor(visibleClosestCurves.last());
+    }
+
+    // Check fills
+    int colorNumber = vectorImage->getColorNumber(getCurrentPoint());
+    return colorNumber;
+}
