@@ -20,7 +20,6 @@ GNU General Public License for more details.
 
 #include <QStringList>
 
-
 class DebugDetails
 {
 public:
@@ -37,7 +36,6 @@ private:
     QStringList mDetails;
 };
 
-
 class Status
 {
 public:
@@ -73,6 +71,11 @@ public:
         ERROR_NEED_AT_LEAST_ONE_CAMERA_LAYER
     };
 
+    struct StatusInt{
+        int value = 0;
+        ErrorCode errorcode = Status::OK;
+    };
+
     Status(ErrorCode code);
     Status(ErrorCode code, const DebugDetails& detailsList, QString title = "", QString description = "");
 
@@ -85,8 +88,10 @@ public:
 
     void setTitle(QString title) { mTitle = title; }
     void setDescription(QString description) { mDescription = description; }
+    void setDetails(DebugDetails dd) { mDetails = dd; }
 
     bool operator==(ErrorCode code) const;
+    bool operator!=(ErrorCode code) const;
 
 private:
     ErrorCode mCode = OK;
@@ -95,6 +100,8 @@ private:
     DebugDetails mDetails;
 };
 
+
+
 #ifndef STATUS_CHECK 
 #define STATUS_CHECK( x )\
 	{ Status st = (x); if (!st.ok()) { return st; } }
